<?php
// Database connection settings
$db_host = 'localhost';      // Usually localhost
$db_name = 'auth';           // Your database name
$db_user = 'root';  // Your database username
$db_pass = 'ascent';  // Your database password

// Set the content type to JSON
// Enable CORS
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: GET");
header("Content-Type: application/json; charset=UTF-8");

try {
    // Connect to the database
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name;charset=utf8", $db_user, $db_pass);
    
    // Set PDO to throw exceptions on error
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    
    // Query to fetch news items from the news table
    // Adjust the column names to match your database schema
    $query = "SELECT id, title, content, date, type FROM news ORDER BY date DESC LIMIT 10";
    
    $stmt = $pdo->prepare($query);
    $stmt->execute();
    
    // Fetch all news items as an array
    $news = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // Format the date for each news item
    foreach ($news as &$item) {
        // Format the date (assumes your date is stored in MySQL date format)
        if (isset($item['date'])) {
            $date = new DateTime($item['date']);
            $item['date'] = $date->format('Y-m-d');
        }
        
        // Make sure all required fields are set
        if (!isset($item['type'])) {
            $item['type'] = 'update'; // Default type
        }
        
        // Clean up content (remove any HTML if needed)
        if (isset($item['content'])) {
            // Optional: strip or allow specific HTML tags
            // $item['content'] = strip_tags($item['content'], '<p><br><strong><em>');
        }
    }
    
    // Return the news items as JSON
    echo json_encode($news);
    
} catch (PDOException $e) {
    // In case of database error, return a friendly error
    $error = ['error' => 'Could not load news data'];
    echo json_encode($error);
    
    // Log the actual error (don't expose this to users)
    error_log('Database error: ' . $e->getMessage());
}
?>